getEveryGuild: Get All Guilds

Description Usage Arguments Value

Description

Gets a listing of all guilds. One of the following attributes must be set: name

Usage

1
2
getEveryGuild(p, ids, name, established, since, status, hasImages, order,
  sort)

Arguments

p

Page Number

ids

ID's of the guilds to return, comma separated. Max 10.

name

Name of a guild

established

Year the guild was established

since

Returns everything that has been updated since that date. Max 30 days. In UNIX timestamp format.

status

Status of the guild in the API

hasImages

Whether the guild has an image or not Y N

order

How the results should be ordered name Default description established status createDate updateDate

sort

How the results should be sorted. ASC Default DESC

Value

id The unique id of the guild.

name The name of the guild.

description The description of the guild.

website The URL to the website for the guild.

images The images object contains URLs to the logo of the guild. This will contain values for icon, medium, and large.

established The year that the guild was established.


samterfa/brewerydb documentation built on June 24, 2019, 12:44 a.m.